import jwt
import unittest
from ridi.cms import cms_client
from ridi.cms.cf_jwt_validator import CFJwtValidator
from ridi.cms.config import Config


test_private = '''
-----BEGIN RSA PRIVATE KEY-----
MIICXAIBAAKBgQC8kGa1pSjbSYZVebtTRBLxBz5H4i2p/llLCrEeQhta5kaQu/Rn
vuER4W8oDH3+3iuIYW4VQAzyqFpwuzjkDI+17t5t0tyazyZ8JXw+KgXTxldMPEL9
5+qVhgXvwtihXC1c5oGbRlEDvDF6Sa53rcFVsYJ4ehde/zUxo6UvS7UrBQIDAQAB
AoGAb/MXV46XxCFRxNuB8LyAtmLDgi/xRnTAlMHjSACddwkyKem8//8eZtw9fzxz
bWZ/1/doQOuHBGYZU8aDzzj59FZ78dyzNFoF91hbvZKkg+6wGyd/LrGVEB+Xre0J
Nil0GReM2AHDNZUYRv+HYJPIOrB0CRczLQsgFJ8K6aAD6F0CQQDzbpjYdx10qgK1
cP59UHiHjPZYC0loEsk7s+hUmT3QHerAQJMZWC11Qrn2N+ybwwNblDKv+s5qgMQ5
5tNoQ9IfAkEAxkyffU6ythpg/H0Ixe1I2rd0GbF05biIzO/i77Det3n4YsJVlDck
ZkcvY3SK2iRIL4c9yY6hlIhs+K9wXTtGWwJBAO9Dskl48mO7woPR9uD22jDpNSwe
k90OMepTjzSvlhjbfuPN1IdhqvSJTDychRwn1kIJ7LQZgQ8fVz9OCFZ/6qMCQGOb
qaGwHmUK6xzpUbbacnYrIM6nLSkXgOAwv7XXCojvY614ILTK3iXiLBOxPu5Eu13k
eUz9sHyD6vkgZzjtxXECQAkp4Xerf5TGfQXGXhxIX52yH+N2LtujCdkQZjXAsGdm
B2zNzvrlgRmgBrklMTrMYgm1NPcW+bRLGcwgW2PTvNM=
-----END RSA PRIVATE KEY-----
'''

test_public = '''
-----BEGIN PUBLIC KEY-----
MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQC8kGa1pSjbSYZVebtTRBLxBz5H
4i2p/llLCrEeQhta5kaQu/RnvuER4W8oDH3+3iuIYW4VQAzyqFpwuzjkDI+17t5t
0tyazyZ8JXw+KgXTxldMPEL95+qVhgXvwtihXC1c5oGbRlEDvDF6Sa53rcFVsYJ4
ehde/zUxo6UvS7UrBQIDAQAB
-----END PUBLIC KEY-----
'''

class TestAdminAuth(unittest.TestCase):
    def setUp(self):
        self.config = Config()
        self.config.RPC_URL = 'http://localhost'
        self.admin_auth = cms_client.AdminAuth(self.config)
        assert self.admin_auth

    def testDecodeJwt(self):
        aud = 'http://example.com'
        token = {
            'iss': 'http://example.org',
            'aud': aud,
            'iat': 1356999524,
            'nbf': 1357000000,
            'email': 'devgrapher@ridi.com',
        }
        encoded = jwt.encode(token, test_private, algorithm='RS256')
        cfjwt = CFJwtValidator()
        payload = cfjwt.decode(encoded, [test_public], aud=aud)

        self.assertEqual(token, payload)

    def testGetPublicKeys(self):
        cfjwt = CFJwtValidator()
        keys = cfjwt.getPublicKeys('https://cms.ridi.io')
        self.assertIsNotNone(keys)

if __name__ == '__main__':
    unittest.main()
